@@ -1,7 +1,7 @@
 package Dist::Zilla::Plugin::Sah::Schemas;
 
-our $DATE = '2016-12-26'; # DATE
-our $VERSION = '0.005'; # VERSION
+our $DATE = '2017-01-09'; # DATE
+our $VERSION = '0.006'; # VERSION
 
 use 5.010001;
 use strict;
@@ -17,6 +17,7 @@ with (
         default_finders => [':InstallModules'],
     },
     'Dist::Zilla::Role::PrereqSource',
+    'Dist::Zilla::Role::RequireFromBuild',
 );
 
 sub _load_schema_modules {
@@ -26,18 +27,11 @@ sub _load_schema_modules {
 
     my %res;
     for my $file (@{ $self->found_files }) {
-        unless ($file->isa("Dist::Zilla::File::OnDisk")) {
-            $self->log_debug(["skipping %s: not an ondisk file, currently only ondisk files are processed", $file->name]);
-            next;
-        }
         next unless $file->name =~ m!^lib/(Sah/Schema/.+\.pm)$!;
+
         my $pkg_pm = $1;
         (my $pkg = $pkg_pm) =~ s/\.pm$//; $pkg =~ s!/!::!g;
-        {
-            local @INC = ("lib", @INC);
-            require $pkg_pm;
-            $res{$pkg} = $file;
-        }
+        $self->require_from_build($pkg_pm);
     }
 
     $self->{_our_schema_modules} = \%res;
@@ -57,11 +51,7 @@ sub _load_schemas_modules {
         next unless $file->name =~ m!^lib/(Sah/Schemas/.+\.pm)$!;
         my $pkg_pm = $1;
         (my $pkg = $pkg_pm) =~ s/\.pm$//; $pkg =~ s!/!::!g;
-        {
-            local @INC = ("lib", @INC);
-            require $pkg_pm;
-            $res{$pkg} = $file;
-        }
+        $self->require_from_build($pkg_pm);
     }
 
     $self->{_our_schemas_modules} = \%res;
@@ -251,7 +241,7 @@ Dist::Zilla::Plugin::Sah::Schemas - Plugin to use when building Sah-Schemas-* di
 
 =head1 VERSION
 
-This document describes version 0.005 of Dist::Zilla::Plugin::Sah::Schemas (from Perl distribution Dist-Zilla-Plugin-Sah-Schemas), released on 2016-12-26.
+This document describes version 0.006 of Dist::Zilla::Plugin::Sah::Schemas (from Perl distribution Dist-Zilla-Plugin-Sah-Schemas), released on 2017-01-09.
 
 =head1 SYNOPSIS
 
@@ -322,7 +312,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by perlancar@cpan.org.
+This software is copyright (c) 2017 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
